@@ -1,4 +1,4 @@
 # -*- coding: utf-8 -*-
 from __future__ import absolute_import, print_function, unicode_literals
 
-from .base import AppHookConfigManager, AppHookConfigQuerySet  # NOQA
+from .base import AppHookConfigManager, AppHookConfigQuerySet  # noqa
