@@ -1,6 +1,9 @@
 # -*- coding: utf-8 -*-
-from django.db.models.query import QuerySet
+from __future__ import absolute_import, print_function, unicode_literals
+
 from django.db.models import Manager
+from django.db.models.query import QuerySet
+from django.utils.translation import ugettext
 
 from ..utils import get_apphook_field_names
 
@@ -15,20 +18,25 @@ class QuerySetMixin(object):
         fields = get_apphook_field_names(self.model)
         if not fields:
             raise ValueError(
-                "Can't find any relation to an ApphookConfig model "
-                "in {0}".format(self.model.__name__)
+                ugettext(
+                    'Can\'t find any relation to an ApphookConfig model in {0}'
+                ).format(self.model.__name__)
             )
         if to and to not in fields:
             raise ValueError(
-                "Can't find relation to ApphookConfig model named "
-                "'{0}' in '{1}'".format(to, self.model.__name__)
+                ugettext(
+                    'Can\'t find relation to ApphookConfig model named '
+                    '"{0}" in "{1}"'
+                ).format(to, self.model.__name__)
             )
         if len(fields) > 1 and to not in fields:
             raise ValueError(
-                "'{0}' has {1} relations to an ApphookConfig model."
-                " Please, specify which one to use in argument 'to'."
-                " Choices are: {2}".format(
-                    self.model.__name__, len(fields), ", ".join(fields)
+                ugettext(
+                    '"{0}" has {1} relations to an ApphookConfig model.'
+                    ' Please, specify which one to use in argument "to".'
+                    ' Choices are: {2}'
+                ).format(
+                    self.model.__name__, len(fields), ', '.join(fields)
                 )
             )
         else:
@@ -58,4 +66,3 @@ class AppHookConfigManager(ManagerMixin, Manager):
     """
     def get_queryset(self):
         return AppHookConfigQuerySet(self.model, using=self.db)
-
